==> classicperipherals-0.2.5-fabric-1.20.1-sources.jar: me/alexdevs/classicPeripherals/upgrades/radio/PocketRadio.java <==
package me.alexdevs.classicPeripherals.upgrades.radio;

import dan200.computercraft.api.peripheral.IPeripheral;
import dan200.computercraft.api.pocket.IPocketAccess;
import dan200.computercraft.api.pocket.IPocketUpgrade;
import me.alexdevs.classicPeripherals.ClassicPeripherals;
import me.alexdevs.classicPeripherals.block.ModBlocks;
import me.alexdevs.classicPeripherals.peripherals.AbstractRadioPeripheral;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_2960;
import org.jspecify.annotations.Nullable;

public class PocketRadio implements IPocketUpgrade {
    public static class RadioPocketPeripheral extends AbstractRadioPeripheral {
        private final IPocketAccess pocket;

        public RadioPocketPeripheral(IPocketAccess pocket) {
            this.pocket = pocket;
        }

        @Override
        public boolean isValid() {
            return true;
        }

        @Override
        public class_1937 getLevel() {
            return pocket.getLevel();
        }

        @Override
        public class_243 getPosition() {
            return pocket.getPosition();
        }

        @Override
        public double getRange() {
            return 0;
        }

        @Override
        public void ping() {

        }

        @Override
        public boolean canBroadcast() {
            return false;
        }

        @Override
        public boolean equals(@Nullable IPeripheral other) {
            return this == other || (other instanceof RadioPocketPeripheral o && pocket == o.pocket);
        }
    }

    private final class_2960 id;
    private final class_1799 stack;

    public PocketRadio(class_2960 id, class_1799 stack) {
        this.id = id;
        this.stack = stack;
    }

    @Override
    public @Nullable IPeripheral createPeripheral(IPocketAccess pocket) {
        return new RadioPocketPeripheral(pocket);
    }

    @Override
    public class_2960 getUpgradeID() {
        return id;
    }

    @Override
    public String getUnlocalisedAdjective() {
        return "Radio";
    }

    @Override
    public class_1799 getCraftingItem() {
        return stack;
    }
}

==> classicperipherals-0.2.6-fabric-1.21.1-sources.jar: me/alexdevs/classicPeripherals/upgrades/radio/PocketRadio.java <==
package me.alexdevs.classicPeripherals.upgrades.radio;

import dan200.computercraft.api.peripheral.IPeripheral;
import dan200.computercraft.api.pocket.AbstractPocketUpgrade;
import dan200.computercraft.api.pocket.IPocketAccess;
import dan200.computercraft.api.pocket.IPocketUpgrade;
import dan200.computercraft.api.upgrades.UpgradeType;
import dan200.computercraft.shared.ModRegistry;
import me.alexdevs.classicPeripherals.ClassicPeripherals;
import me.alexdevs.classicPeripherals.block.ModBlocks;
import me.alexdevs.classicPeripherals.peripherals.AbstractRadioPeripheral;
import me.alexdevs.classicPeripherals.upgrades.ModUpgrades;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import org.jspecify.annotations.Nullable;

public class PocketRadio extends AbstractPocketUpgrade {
    public static class RadioPocketPeripheral extends AbstractRadioPeripheral {
        private final IPocketAccess pocket;

        public RadioPocketPeripheral(IPocketAccess pocket) {
            this.pocket = pocket;
        }

        @Override
        public boolean isValid() {
            return true;
        }

        @Override
        public class_1937 getLevel() {
            return pocket.getLevel();
        }

        @Override
        public class_243 getPosition() {
            return pocket.getPosition();
        }

        @Override
        public double getRange() {
            return 0;
        }

        @Override
        public void ping() {

        }

        @Override
        public boolean canBroadcast() {
            return false;
        }

        @Override
        public boolean equals(@Nullable IPeripheral other) {
            return this == other || (other instanceof RadioPocketPeripheral o && pocket == o.pocket);
        }
    }

    public PocketRadio(class_1799 stack) {
        super("radio", stack);
    }

    @Override
    public UpgradeType<? extends IPocketUpgrade> getType() {
        return ModUpgrades.POCKET_RADIO;
    }


    @Override
    public @Nullable IPeripheral createPeripheral(IPocketAccess access) {
        return new PocketRadio.RadioPocketPeripheral(access);
    }
}
